# FeedIndicatorsRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**bypass_exclusion_list** | **bool** |  | [optional] 
**classifier_id** | **str** |  | [optional] 
**indicators** | [**list[RawFeedIndicator]**](RawFeedIndicator.md) |  | [optional] 
**mapper_id** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


